'use strict';

var _connectorServer = require('./connector-server');

var _connectorServer2 = _interopRequireDefault(_connectorServer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

describe('ConnectorServer', () => {
  let connector;

  describe('constructor', () => {
    it('should have a constructor method', () => {
      expect(_connectorServer2.default).to.have.property('constructor').that.is.a('function');
    });

    it('should initialize the instance properly (default)', () => {
      expect(new _connectorServer2.default()).to.have.property('_dsn').that.equals('http://localhost:9000');
    });

    it('should initialize the instance properly (custom dsn)', () => {
      expect(new _connectorServer2.default({ dsn: 'dsn-stub' })).to.have.property('_dsn').that.equals('dsn-stub');
    });

    it('should initialize the instance properly (basic auth username)', () => {
      expect(new _connectorServer2.default({ username: 'username-stub' })).to.have.property('_username').that.equals('username-stub');
    });

    it('should initialize the instance properly (basic auth password)', () => {
      expect(new _connectorServer2.default({ password: 'password-stub' })).to.have.property('_password').that.equals('password-stub');
    });
  });

  describe('get', () => {
    beforeEach(() => {
      connector = new _connectorServer2.default();
      sinon.stub(connector, '_makeRequest').returns(Promise.resolve('corenlp-result-stub'));
    });

    context('standard annotation pipeline', () => {
      it('should prepare the request propery', _asyncToGenerator(function* () {
        connector.get({
          annotators: ['a', 'b', 'c'],
          text: 'xyz',
          options: { optionA: 1, optionB: 2 },
          language: 'LanguageStub'
        });
        expect(connector._makeRequest).to.be.have.been.calledWith('http://localhost:9000', 'pipelineLanguage=LanguageStub&properties={"annotators":"a,b,c","optionA":1,"optionB":2,"outputFormat":"json"}', 'xyz');
      }));
    });

    context('utility pipeline', () => {
      it('should prepare the request propery', _asyncToGenerator(function* () {
        connector.get({
          annotators: ['a', 'b', 'c'],
          text: 'xyz',
          options: { optionA: 1, optionB: 2, 'semgrex.pattern': '{ner:/.*/}=stub' },
          language: 'LanguageStub',
          utility: 'semgrex'
        });
        expect(connector._makeRequest).to.be.have.been.calledWith('http://localhost:9000/semgrex', 'pipelineLanguage=LanguageStub&properties={"annotators":"a,b,c","optionA":1,"optionB":2,"semgrex.pattern":"{ner:/.*/}=stub","outputFormat":"json"}&pattern=%7Bner:/.*/%7D=stub', 'xyz');
      }));
    });
  });

  describe('_makeRequest', () => {
    describe('no authentincation', () => {
      beforeEach(() => {
        connector = new _connectorServer2.default();
        sinon.stub(connector, '_rp').returns(Promise.resolve('corenlp-result-stub'));
      });

      it('should call request-promise accordingly', _asyncToGenerator(function* () {
        connector._makeRequest('http://127.0.0.1:3000', 'q=1&k=2', 'text-stub');
        expect(connector._rp).to.be.have.been.calledWith({
          method: 'POST',
          uri: 'http://127.0.0.1:3000?q=1&k=2',
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
          },
          body: 'text-stub',
          json: true
        });
      }));
    });

    describe('basic authentincation', () => {
      beforeEach(() => {
        connector = new _connectorServer2.default({ username: 'username-stub', password: 'password-stub' });
        sinon.stub(connector, '_rp').returns(Promise.resolve('corenlp-result-stub'));
      });

      it('should call request-promise accordingly', _asyncToGenerator(function* () {
        connector._makeRequest('http://127.0.0.1:3000', 'q=1&k=2', 'text-stub');
        expect(connector._rp).to.be.have.been.calledWith({
          method: 'POST',
          uri: 'http://127.0.0.1:3000?q=1&k=2',
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
          },
          body: 'text-stub',
          json: true,
          auth: {
            user: 'username-stub',
            pass: 'password-stub'
          }
        });
      }));
    });
  });
});